# Examples

Example projects showing how to write build scripts.

* [basic](./basic) - Basic project showing basic targets and environment arguments.
* [contexts](./contexts) - Project that uses contexts project.
